cyfunc
======

.. image:: https://github.com/tillahoffmann/cyfunc/workflows/CI/badge.svg
  :target: https://github.com/tillahoffmann/cyfunc/actions?query=workflow%3A%22CI%22

.. image:: https://img.shields.io/pypi/v/cyfunc.svg?style=flat-square
   :target: https://pypi.python.org/pypi/cyfunc

.. image:: https://readthedocs.org/projects/cyfunc/badge/?version=latest
  :target: https://cyfunc.readthedocs.io/en/latest/?badge=latest

Easy `universal functions <https://numpy.org/doc/stable/reference/ufuncs.html>`__ for numpy in cython.
